@@ -23,6 +23,7 @@ __all__ = (
     "AccessTypeType",
     "ChannelStateType",
     "GetChannelSchedulePaginatorName",
+    "ListAlertsPaginatorName",
     "ListChannelsPaginatorName",
     "ListPlaybackConfigurationsPaginatorName",
     "ListSourceLocationsPaginatorName",
@@ -39,6 +40,7 @@ __all__ = (
 AccessTypeType = Literal["S3_SIGV4", "SECRETS_MANAGER_ACCESS_TOKEN"]
 ChannelStateType = Literal["RUNNING", "STOPPED"]
 GetChannelSchedulePaginatorName = Literal["get_channel_schedule"]
+ListAlertsPaginatorName = Literal["list_alerts"]
 ListChannelsPaginatorName = Literal["list_channels"]
 ListPlaybackConfigurationsPaginatorName = Literal["list_playback_configurations"]
 ListSourceLocationsPaginatorName = Literal["list_source_locations"]
